import { createApp } from 'vue'
import { createPinia } from 'pinia'
import * as Sentry from '@sentry/vue'

import 'uno.css'

import ElementPlus from 'element-plus'
import 'element-plus/dist/index.css'
import * as ElementPlusIconsVue from '@element-plus/icons-vue'
// import { install } from '@icon-park/vue-next/es/all'

import registerComponent from '@/components/index'
import registerVxeTable from '@/components/VxeTable'
import directives from '@/directive'

import FsAdminCore from '@fskj-admin/core'
import '@fskj-admin/core/lib/style.css'
import uploadConfig from './config/uploadConfig'

import App from './App.vue'
import router from './router'

import './assets/main.css'
import 'virtual:svg-icons-register'

// import WujieVue from 'wujie-vue3'

const app = createApp(App)

app.use(createPinia())
app.use(router)
app.use(ElementPlus)

app.use(FsAdminCore, {
  upload: uploadConfig
})
// app.use(WujieVue)
app.use(directives)
registerComponent(app)
registerVxeTable(app)

for (const [key, component] of Object.entries(ElementPlusIconsVue)) {
  app.component(key, component)
}

// install(app)

import.meta.env.VITE_SENTRY_DSN &&
  Sentry.init({
    app,
    dsn: import.meta.env.VITE_SENTRY_DSN,
    integrations: [Sentry.browserTracingIntegration(), Sentry.replayIntegration()],
    tracesSampleRate: 1.0,
    tracePropagationTargets: [],
    replaysSessionSampleRate: 0.1,
    replaysOnErrorSampleRate: 1.0
  })

app.mount('#app')
